@@ -69,6 +69,15 @@ class SoSComponent():
         "verbosity": 0
     }
 
+    # files in collected archive that might contain upload password
+    files_with_upload_passwd = [
+        "sos_logs/sos.log",
+        "sos_reports/manifest.json",
+        "sos_commands/process/ps_*",
+        "sos_commands/selinux/ps_*",
+        "sos_commands/systemd/systemctl_status_--all",
+    ]
+
     def __init__(self, parser, parsed_args, cmdline_args):
         self.parser = parser
         self.args = parsed_args
@@ -82,8 +91,12 @@ class SoSComponent():
         try:
             import signal
             signal.signal(signal.SIGTERM, self.get_exit_handler())
-        except Exception:
-            pass
+        except Exception as err:
+            sys.stdout.write(f"Notice: Could not set SIGTERM handler: {err}\n")
+
+        self.opts = SoSOptions(arg_defaults=self._arg_defaults)
+        if self.load_policy:
+            self.load_local_policy()
 
         # update args from component's arg_defaults definition
         self._arg_defaults.update(self.arg_defaults)
@@ -96,7 +109,7 @@ class SoSComponent():
 
             if not os.path.isdir(tmpdir) \
                     or not os.access(tmpdir, os.W_OK):
-                msg = "temporary directory %s " % tmpdir
+                msg = f"temporary directory {tmpdir} "
                 msg += "does not exist or is not writable\n"
                 # write directly to stderr as logging is not initialised yet
                 sys.stderr.write(msg)
@@ -108,9 +121,6 @@ class SoSComponent():
             self.tempfile_util = TempFileUtil(self.tmpdir)
             self._setup_logging()
 
-        if self.load_policy:
-            self.load_local_policy()
-
         if self.manifest is not None:
             self.manifest.add_field('version', __version__)
             self.manifest.add_field('cmdline', ' '.join(self.cmdline))
@@ -121,7 +131,7 @@ class SoSComponent():
             self.manifest.add_field('compression', '')
             self.manifest.add_field('tmpdir', self.tmpdir)
             self.manifest.add_field('tmpdir_fs_type', self.tmpfstype)
-            self.manifest.add_field('policy', self.policy.distro)
+            self.manifest.add_field('policy', self.policy.os_release_name)
             self.manifest.add_section('components')
 
     def load_local_policy(self):
@@ -138,7 +148,7 @@ class SoSComponent():
         raise NotImplementedError
 
     def get_exit_handler(self):
-        def exit_handler(signum, frame):
+        def exit_handler(signum, frame):  # pylint: disable=unused-argument
             self.exit_process = True
             self._exit()
         return exit_handler
@@ -165,7 +175,7 @@ class SoSComponent():
         # no standard library method exists for this, so call out to stat to
         # avoid bringing in a dependency on psutil
         self.tmpfstype = shell_out(
-            "stat --file-system --format=%s %s" % ("%T", tmpdir)
+            f"stat --file-system --format=%T {tmpdir}"
         ).strip()
 
         if self.tmpfstype == 'tmpfs':
@@ -181,14 +191,15 @@ class SoSComponent():
     def check_listing_options(self):
         opts = [o for o in self.opts.dict().keys() if o.startswith('list')]
         if opts:
-            return any([getattr(self.opts, opt) for opt in opts])
+            return any(getattr(self.opts, opt) for opt in opts)
+        return False
 
     @classmethod
     def add_parser_options(cls, parser):
         """This should be overridden by each subcommand to add its own unique
         options to the parser
         """
-        pass
+        raise NotImplementedError
 
     def apply_options_from_cmdline(self, opts):
         """(Re-)apply options specified via the cmdline to an options instance
@@ -264,6 +275,28 @@ class SoSComponent():
 
         opts = self.apply_options_from_cmdline(opts)
 
+        # user specified command line preset
+        self.preset = None
+        if hasattr(opts, 'preset'):
+            if opts.preset != self._arg_defaults["preset"]:
+                self.preset = self.policy.find_preset(opts.preset)
+                if not self.preset:
+                    sys.stderr.write(f"Unknown preset: '{opts.preset}'\n")
+                    self.preset = self.policy.probe_preset()
+                    opts.list_presets = True
+
+            # --preset=auto
+            if not self.preset:
+                self.preset = self.policy.probe_preset()
+            # now merge preset options to opts
+            opts.merge(self.preset.opts)
+            # re-apply any cmdline overrides to the preset
+            opts = self.apply_options_from_cmdline(opts)
+
+            if hasattr(self.preset.opts, 'verbosity') and \
+                    self.preset.opts.verbosity > 0:
+                self.set_loggers_verbosity(self.preset.opts.verbosity)
+
         return opts
 
     def cleanup(self):
@@ -277,8 +310,8 @@ class SoSComponent():
             if self.tmpdir:
                 rmtree(self.tmpdir)
         except Exception as err:
-            print("Failed to finish cleanup: %s\nContents may remain in %s"
-                  % (err, self.tmpdir))
+            print(f"Failed to finish cleanup: {err}\nContents may remain in "
+                  f"{self.tmpdir}")
 
     def _set_encrypt_from_env_vars(self):
         msg = ('No encryption environment variables set, archive will not be '
@@ -320,8 +353,7 @@ class SoSComponent():
         if self.opts.encrypt:
             self._get_encryption_method()
         enc_opts = {
-            'encrypt': True if (self.opts.encrypt_pass or
-                                self.opts.encrypt_key) else False,
+            'encrypt': self.opts.encrypt_pass or self.opts.encrypt_key,
             'key': self.opts.encrypt_key,
             'password': self.opts.encrypt_pass
         }
@@ -343,6 +375,23 @@ class SoSComponent():
 
         self.archive.set_debug(self.opts.verbosity > 2)
 
+    def _obfuscate_upload_passwords(self):
+        # obfuscate strings like:
+        # --upload-pass=PASSWORD
+        # --upload-pass PASSWORD
+        # --upload-url https://user:PASSWORD@some.url
+        # in both sos_logs/sos.log and in sos_reports/manifest.json
+        # and several sos_commands/* places from plugins's collected data
+        _arc_path = self.archive.get_archive_path()
+        for path in self.files_with_upload_passwd:
+            for f in Path(_arc_path).glob(path):
+                # get just the relative path that archive works with
+                f = os.path.relpath(f, _arc_path)
+                for re in [r"(--upload-pass[\s=]+)\S+",
+                           r"(--upload-url[\s=]+\S+://.*:)([^@]*)",
+                           r"(--upload-s3-secret-key[\s=]+)\S+"]:
+                    self.archive.do_file_sub(f, re, r"\1********")
+
     def add_ui_log_to_stdout(self):
         ui_console = logging.StreamHandler(sys.stdout)
         ui_console.setFormatter(logging.Formatter('%(message)s'))
@@ -352,15 +401,13 @@ class SoSComponent():
         self.ui_log.addHandler(ui_console)
 
     def set_loggers_verbosity(self, verbosity):
-        if verbosity:
-            if self.flog:
-                self.flog.setLevel(logging.DEBUG)
-            if self.opts.verbosity > 1:
+        if getattr(self, 'flog', None) and verbosity:
+            self.flog.setLevel(logging.DEBUG)
+        if getattr(self, 'console', None):
+            if verbosity and self.opts.verbosity > 1:
                 self.console.setLevel(logging.DEBUG)
             else:
                 self.console.setLevel(logging.WARNING)
-        else:
-            self.console.setLevel(logging.WARNING)
 
     def _setup_logging(self):
         """Creates the log handler that shall be used by all components and any
@@ -432,10 +479,7 @@ class SoSMetadata():
         return self._values[item]
 
     def __getattr__(self, attr):
-        try:
-            return self._values[attr]
-        except Exception:
-            raise AttributeError(attr)
+        return self._values[attr]
 
     def add_field(self, field_name, content):
         """Add a key, value entry to the current metadata instance
